# BurnAfter(Reading)

The BurnAfter(Reading) module provides a custom entity type for creating
sensitive content that automatically deletes after a specified number of views
or a set expiration time, whichever happens first. It supports optional
encryption of content using the [encrypt](https://www.drupal.org/project/encrypt) module.

- For a full description of the module, visit the
[project page](https://www.drupal.org/project/burnafter).

- To submit bug reports or feature suggestions, or track changes
[issue queue](https://www.drupal.org/project/issues/burnafter).

## Table of contents

- Requirements
- Installation
- Configuration
- Usage
- Maintainers


## Requirements

Ensure Drupal cron runs regularly.

### Optional (but recommended)

If you're sharing sensitive content, it is recommended you install the following:

- [Encrypt](https://www.drupal.org/project/encrypt)
- [Real AES](https://www.drupal.org/project/real_aes)


## Installation

Install as you would normally install a contributed Drupal module.
Visit [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules)
for further information.


## Configuration

- Enable the module.
- Grant the 'view burnafter entity' permission where appropriate.

### Enable encryption

The below is an example of an encryption scenario using Real AES.
Feel free to adjust according to your requirements.

- Generate a 256-bit AES key using OpenSSL:
  ```bash
  openssl rand -base64 32 >/var/keys/aes256.key
  chmod 0600 /var/keys/aes256.key
  chown www-data: /var/keys/aes256.key
  ```
- Go to `/admin/config/system/keys` and add a key:
  - Key name: e.g., aes256-burnafter
  - Key type: Encryption
  - Key size: 256
  - Key provider: File
  - File location: Path to your key file (e.g., /var/keys/aes256.key)
  - Base64-encoded: Check this box
  - Save.
- Go to `/admin/config/system/encryption/profiles` and add a profile:
  - Label: e.g., AES256 BurnAfter
  - Encryption Method: Authenticated AES (Real AES)
  - Encryption Key: Select the key (e.g., aes256-burnafter)
  - Save.
- Go to `/admin/config/system/burnafter` and enable encryption:
  - Enable encryption: Check this box.
  - Encryption profile: Select the profile created above.
  - Save.


## Usage

Visit `/burnafter/add` to create a self-destructing entity.
Enter your sensitive content, set the maximum number of views, and
choose an expiration time (defaults to 30 minutes from now).

Upon saving, a unique UUID-based URL will be generated.
Share this link securely, but act fast--it’s only valid until the view limit
or expiration time is reached!


## Maintainers

- Greg Mack - [gregcube](https://www.drupal.org/u/gregcube)

