<?php declare(strict_types=1);

namespace Drupal\burnafter\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\burnafter\Entity\BurnAfterEntityInterface;
use Drupal\burnafter\BurnAfterServiceInterface;
use Drupal\encrypt\Exception\EncryptException;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;

/**
 * Provides BurnAfterController.
 */
final class BurnAfterController extends ControllerBase {

  /**
   * Constructs a BurnAfterController object.
   *
   * @param \Drupal\burnafter\BurnAfterService $burnAfterService.
   */
  public function __construct(
    private readonly BurnAfterServiceInterface $burnAfterService
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new static($container->get('burnafter'));
  }

  /**
   * Callback for burnafter.view route.
   *
   * @param \Drupal\burnafter\Entity\BurnAfterEntityInterface $burnafter
   */
  public function view(BurnAfterEntityInterface $burnafter): array {
    $content = $burnafter->get('content')->value;

    if ($this->burnAfterService->shouldEncrypt()) {
      try {
        $content = $this->burnAfterService->decrypt($content);
      }
      catch (EncryptException $e) {
        $this->messenger()->addError($this->t('Content unavailable due to decryption error.'));
        throw new AccessDeniedHttpException($e->getMessage(), $e);
      }
    }

    $burnafter->set('view_count', $burnafter->get('view_count')->value + 1);
    $burnafter->save();

    return [
      '#type' => 'html_tag',
      '#tag' => 'pre',
      '#plain_text' => $content,
      '#cache' => ['max-age' => 0],
    ];
  }

}

// vim: expandtab ts=2 sw=2

