<?php declare(strict_types=1);

namespace Drupal\burnafter\EventSubscriber;

use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\burnafter\Entity\BurnAfterEntityInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\RequestEvent;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Subscriber to handle BurnAfter entity deletion.
 */
final class BurnAfterSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a BurnAfterSubscriber object.
   */
  public function __construct(
    private readonly CurrentRouteMatch $routeMatch
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [KernelEvents::REQUEST => ['onKernelRequest', 27]];
  }

  /**
   * Check if a BurnAfter entity should be deleted.
   */
  public function onKernelRequest(RequestEvent $event): void {
    if (!$event->isMainRequest() || $this->routeMatch->getRouteName() !== 'burnafter.view') {
      return;
    }

    $burnafter = $this->routeMatch->getParameter('burnafter');
    if (!$burnafter instanceOf BurnAfterEntityInterface) {
      return;
    }

    if ($burnafter->shouldDelete()) {
      $burnafter->delete();
      throw new NotFoundHttpException();
    }
  }

}

// vim: expandtab ts=2 sw=2

