<?php declare(strict_types=1);

namespace Drupal\burnafter\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\burnafter\BurnAfterServiceInterface;
use Drupal\encrypt\Exception\EncryptException;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides BurnAfterForm for a BurnAfterEntity.
 */
final class BurnAfterForm extends ContentEntityForm {

  private readonly BurnAfterServiceInterface $burnAfterService;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    EntityRepositoryInterface $entity_repository,
    EntityTypeBundleInfoInterface $entity_type_bundle_info,
    TimeInterface $time,
    BurnAfterServiceInterface $burnafter_service
  ) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
    $this->burnAfterService = $burnafter_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('burnafter')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    if ($this->burnAfterService->shouldEncrypt()) {
      try {
        $content = $form_state->getValue('content')[0]['value'];
        $this->burnAfterService->encrypt($content);
      }
      catch (\RuntimeException $e) {
        $form_state->setErrorByName('content', $e->getMessage());
      }
      catch (EncryptException $e) {
        $form_state->setErrorByName('content', $e->getMessage());
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): int {
    $status = parent::save($form, $form_state);

    $this->messenger()->addStatus($this->t('Share this link: %url', [
      '%url' => $this->entity->toUrl()->setOptions(['absolute' => TRUE])->toString(),
    ]));

    return $status;
  }

}

// vim: expandtab ts=2 sw=2

