<?php declare(strict_types=1);

namespace Drupal\burnafter\Routing;

use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\ParamConverter\ParamConverterInterface;
use Symfony\Component\Routing\Route;

/**
 * Provides a route parameter converter for upcasting a UUID to the
 * corresponding burnafter entity.
 */
final class UuidParamConverter implements ParamConverterInterface {

  /**
   * Constructs a new UuidParamConverter.
   *
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entityRepository
   */
  public function __construct(
    private readonly EntityRepositoryInterface $entityRepository
  ) {}

  /**
   * {@inheritdoc}
   */
  public function convert($value, $definition, $name, array $defaults) {
    return $this->entityRepository->loadEntityByUuid('burnafter', $value);
  }

  /**
   * {@inheritdoc}
   */
  public function applies($definition, $name, Route $route) {
    return !empty($definition['type']) && $definition['type'] === 'burnafter-uuid';
  }

}

// vim: expandtab ts=2 sw=2

